Hi!

Thank you very much for your submission to Ansible.  It means a lot to us that you've taken the time to contribute.

Unfortunately, we're not currently accepting most outside contributions consisting only of minor changes such as:

* Spelling, grammar or typo fixes in comments, code or tests.
* Type annotations for existing code.
* Code style changes.

However, we're always up for discussion.

Because this project is very active, we're unlikely to see comments made on closed tickets and we lock them after some time.
If you or anyone else has any further questions, please let us know by using any of the communication methods listed on the page below:

* <https://docs.ansible.com/ansible/latest/community/communication.html>

In the future, sometimes starting a discussion on the Ansible Forum before implementing
a feature can make getting things included a little easier, but it's not always necessary.

Thank you once again for this and your interest in Ansible!
